@@ -33,9 +33,10 @@
 #  define SOLID_DEPRECATED_NO_EXPORT SOLID_NO_EXPORT SOLID_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define SOLID_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef SOLID_NO_DEPRECATED
+#    define SOLID_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
